@@ -32,36 +32,63 @@ class WialonObjectFactory:
     @overload
     def create(self, items_type: Literal["user"], *args, **kwargs) -> WialonUser: ...
 
+    @overload
+    def get(self, items_type: Literal["user"], id: int | str) -> WialonUser: ...
+
     @overload
     def create(
         self, items_type: Literal["account"], *args, **kwargs
     ) -> WialonAccount: ...
 
+    @overload
+    def get(self, items_type: Literal["account"], id: int | str) -> WialonAccount: ...
+
     @overload
     def create(
         self, items_type: Literal["avl_resource"], *args, **kwargs
     ) -> WialonResource: ...
 
+    @overload
+    def get(
+        self, items_type: Literal["avl_resource"], id: int | str
+    ) -> WialonResource: ...
+
     @overload
     def create(
         self, items_type: Literal["avl_retranslator"], *args, **kwargs
     ) -> WialonRetranslator: ...
 
+    @overload
+    def get(
+        self, items_type: Literal["avl_retranslator"], id: int | str
+    ) -> WialonRetranslator: ...
+
     @overload
     def create(
         self, items_type: Literal["avl_route"], *args, **kwargs
     ) -> WialonRoute: ...
 
+    @overload
+    def get(self, items_type: Literal["avl_route"], id: int | str) -> WialonRoute: ...
+
     @overload
     def create(
         self, items_type: Literal["avl_unit"], *args, **kwargs
     ) -> WialonUnit: ...
 
+    @overload
+    def get(self, items_type: Literal["avl_unit"], id: int | str) -> WialonUnit: ...
+
     @overload
     def create(
         self, items_type: Literal["avl_unit_group"], *args, **kwargs
     ) -> WialonUnitGroup: ...
 
+    @overload
+    def get(
+        self, items_type: Literal["avl_unit_group"], id: int | str
+    ) -> WialonUnitGroup: ...
+
     def create(self, items_type: str, *args, **kwargs) -> WialonObject:
         """Creates a Wialon object in Wialon and returns its Python equivalent."""
         cls = self._get_wialon_cls(items_type)
